@@ -6,10 +6,12 @@ import traceback
 import importlib
 from types import ModuleType
 
+from a2wsgi import WSGIMiddleware
 from starlette.types import Scope, Receive, Send, ASGIApp, Message
 from starlette.status import WS_1001_GOING_AWAY
-from starlette.requests import URL, Request
-from starlette.websockets import WebSocket, WebSocketClose
+from starlette.requests import URL
+from starlette.websockets import WebSocketClose
+from starlette.staticfiles import StaticFiles
 from starlette.responses import RedirectResponse
 from starlette.middleware import Middleware
 from starlette.middleware.errors import ServerErrorMiddleware
@@ -22,28 +24,30 @@ from starlette.routing import NoMatchFound
 from .types import WSGIApp
 from .utils import Singleton
 from .config import here, Config
-from .responses import FileResponse, TemplateResponse, automatic
-from .background import (
+from .http.request import Request
+from .http.responses import FileResponse, TemplateResponse, Jinja2Templates
+from .http.background import (
     BackgroundTasks,
     after_response_tasks_var,
     finished_response_tasks_var,
 )
-from .wsgi import WSGIMiddleware
+from .websocket.request import WebSocket
+from .preset import (
+    check_on_startup,
+    clear_check_on_shutdown,
+    create_directories,
+    clear_directories,
+)
 
 
 class Lifespan:
-    def __init__(self) -> None:
-        self.on_startup: typing.Dict[str, typing.Callable] = {}
-        self.on_shutdown: typing.Dict[str, typing.Callable] = {}
-
-    def on_event(self, event_type: str) -> typing.Callable:
-        """Wrapper add_event_type"""
-
-        def add_event_handler(func: typing.Callable) -> typing.Callable:
-            self.add_event_handler(event_type, func)
-            return func
-
-        return add_event_handler
+    def __init__(
+        self,
+        on_startup: typing.Dict[str, typing.Callable] = None,
+        on_shutdown: typing.Dict[str, typing.Callable] = None,
+    ) -> None:
+        self.on_startup: typing.Dict[str, typing.Callable] = on_startup or {}
+        self.on_shutdown: typing.Dict[str, typing.Callable] = on_shutdown or {}
 
     def add_event_handler(self, event_type: str, func: typing.Callable) -> None:
         if event_type == "startup":
@@ -100,6 +104,9 @@ class Lifespan:
 
 
 class IndexFile:
+    HTTPClass = Request
+    WebSocketClass = WebSocket
+
     def __init__(self, module_name: str, basepath: str, try_html: bool = False) -> None:
         self.module_name = module_name
         self.basepath = basepath
@@ -205,13 +212,13 @@ class IndexFile:
                 yield module, path
 
     async def http(self, scope: Scope, receive: Receive, send: Send) -> None:
-        request = Request(scope, receive)
+        request = self.HTTPClass(scope, receive, send)
         pathlist = self._split_path(request.url.path)
 
         module = self.get_view(request.url.path)
         if not hasattr(module, "HTTP"):
             if self.try_html:
-                pathlist = pathlist[1:]  # delete module_name from pathlist
+                pathlist = pathlist[1:]  # delete self.module_name from pathlist
                 try:
                     # only html, no middleware/background tasks or other anything
                     await TemplateResponse(
@@ -239,10 +246,6 @@ class IndexFile:
 
             # get response
             response = await get_response(request)
-            if isinstance(response, tuple):
-                response = automatic(*response)
-            else:
-                response = automatic(response)
             response.background = after_response_tasks_var.get()
             await response(scope, receive, send)
         finally:
@@ -253,7 +256,7 @@ class IndexFile:
             await run_finished_response_tasks()
 
     async def websocket(self, scope: Scope, receive: Receive, send: Send) -> None:
-        websocket = WebSocket(scope, receive=receive, send=send)
+        websocket = self.WebSocketClass(scope, receive=receive, send=send)
 
         module = self.get_view(websocket.url.path)
         if not hasattr(module, "Socket"):
@@ -284,10 +287,38 @@ class IndexFile:
 
 class Index(metaclass=Singleton):
     def __init__(self) -> None:
+        config = Config()
+
         self.indexfile = IndexFile("views", here, True)
-        self.lifespan = Lifespan()
-        self.mount_apps: typing.List[typing.Tuple[str, ASGIApp]] = []
-        self.user_middlewares: typing.List[Middleware] = []
+        self.templates = Jinja2Templates(config.TEMPLATES)
+        self.lifespan = Lifespan(
+            on_startup={
+                check_on_startup.__qualname__: check_on_startup,
+                create_directories.__qualname__: create_directories,
+            },
+            on_shutdown={
+                clear_check_on_shutdown.__qualname__: clear_check_on_shutdown,
+                clear_directories.__qualname__: clear_directories,
+            },
+        )
+        self.mount_apps: typing.List[typing.Tuple[str, ASGIApp]] = [
+            (
+                "/static",
+                StaticFiles(directory=os.path.join(here, "static"), check_dir=False),
+            ),
+        ]
+        self.user_middlewares: typing.List[Middleware] = [
+            Middleware(
+                CORSMiddleware,
+                allow_origins=config.CORS_ALLOW_ORIGINS,
+                allow_methods=config.CORS_ALLOW_METHODS,
+                allow_headers=config.CORS_ALLOW_HEADERS,
+                allow_credentials=config.CORS_ALLOW_CREDENTIALS,
+                allow_origin_regex=config.CORS_ALLOW_ORIGIN_REGEX,
+                expose_headers=config.CORS_EXPOSE_HEADERS,
+                max_age=config.CORS_MAX_AGE,
+            ),
+        ]
         self.exception_handlers: typing.Dict[
             typing.Union[int, typing.Type[Exception]], typing.Callable
         ] = {}
@@ -309,16 +340,7 @@ class Index(metaclass=Singleton):
                 exception_handlers[key] = value
 
         middlewares = [
-            Middleware(
-                CORSMiddleware,
-                allow_origins=config.CORS_ALLOW_ORIGINS,
-                allow_methods=config.CORS_ALLOW_METHODS,
-                allow_headers=config.CORS_ALLOW_HEADERS,
-                allow_credentials=config.CORS_ALLOW_CREDENTIALS,
-                allow_origin_regex=config.CORS_ALLOW_ORIGIN_REGEX,
-                expose_headers=config.CORS_EXPOSE_HEADERS,
-                max_age=config.CORS_MAX_AGE,
-            ),
+            Middleware(TrustedHostMiddleware, allowed_hosts=config.ALLOWED_HOSTS),
             Middleware(
                 ServerErrorMiddleware, handler=error_handler, debug=config.DEBUG
             ),
@@ -328,7 +350,6 @@ class Index(metaclass=Singleton):
             middlewares.append(Middleware(HTTPSRedirectMiddleware))
 
         middlewares += [
-            Middleware(TrustedHostMiddleware, allowed_hosts=config.ALLOWED_HOSTS),
             Middleware(
                 ExceptionMiddleware, handlers=exception_handlers, debug=config.DEBUG
             ),
@@ -369,9 +390,34 @@ class Index(metaclass=Singleton):
         self.lifespan.add_event_handler("shutdown", func)
         return func
 
+    def mount_asgi(self, route: str, app: ASGIApp) -> None:
+        """
+        mount ASGI app
+        """
+        if route != "":  # allow use "" to mount app
+            assert route.startswith("/"), "route must be start with '/'"
+            assert not route.endswith("/"), "route can't end with '/'"
+        self.mount_apps.append((route, app))
+
+    def mount_wsgi(self, route: str, app: WSGIApp) -> None:
+        """
+        mount WSGI app
+        """
+        if route != "":  # allow use "" to mount app
+            assert route.startswith("/"), "route must be start with '/'"
+            assert not route.endswith("/"), "route can't end with '/'"
+        self.mount_apps.append((route, WSGIMiddleware(app)))
+
     def mount(
         self, route: str, app: typing.Union[ASGIApp, WSGIApp], app_type: str
     ) -> None:
+        import warnings
+
+        warnings.warn(
+            "`mount` method has been deprecated and will be removed in version 0.11.0 !",
+            DeprecationWarning,
+            stacklevel=2,
+        )
         assert app_type in ("asgi", "wsgi")
         if route != "":  # allow use "" to mount app
             assert route.startswith("/"), "prefix must be start with '/'"
@@ -416,6 +462,9 @@ class Index(metaclass=Singleton):
                 except NoMatchFound:
                     if has_received:  # has call received
                         raise HTTPException(404)
+                except HTTPException as e:
+                    if e.status_code != 404 or has_received:
+                        raise e
 
             try:
                 await self.indexfile(scope, receive, send)
