@@ -13,8 +13,15 @@ import uvicorn
 from .utils import import_module
 from .config import here, LOG_LEVELS, Config
 from .applications import Index
-from .test import cmd_test
-from .autoreload import cmd_check
+
+try:
+    from .test import cmd_test
+except ImportError as e:
+
+    def cmd_test(raise_exception=e):  # type: ignore
+        raise raise_exception
+
+
 from .__version__ import __version__
 
 
@@ -40,7 +47,7 @@ def execute(command: Union[List[str], str]) -> int:
     while process.poll() is None:
         time.sleep(1)
 
-    return process.poll()
+    return process.returncode
 
 
 @click.group(help=f"Index.py {__version__}")
@@ -53,7 +60,7 @@ def main(env, debug):
     config.import_from_environ()
     Index().rebuild_app()
     # set index logger level
-    logging.getLogger("indexpy").setLevel(LOG_LEVELS[config.log_level])
+    logging.getLogger("indexpy").setLevel(LOG_LEVELS[config.LOG_LEVEL])
 
 
 @main.command(help="use only uvicorn to deploy")
@@ -81,9 +88,6 @@ def serve(application):
 @click.argument("method", type=click.Choice(["start", "stop", "reload"]))
 @click.argument("application", default="indexpy:app")
 def gunicorn(workers, daemon, configuration, method, application):
-    if sys.platform in ("win32", "cygwin", "msys"):
-        raise RuntimeError("gunicorn can't run on windows system.")
-
     if method == "start":
         command = [
             "gunicorn -k uvicorn.workers.UvicornWorker",
@@ -109,6 +113,5 @@ def gunicorn(workers, daemon, configuration, method, application):
 
 
 main.command(name="test", help="run test")(cmd_test)
-main.command(name="check", help="check .py file in program")(cmd_check)
 
 import_module("commands")
