@@ -1,15 +1,18 @@
 import os
 import ast
+import sys
 import typing
-import unittest
 
 import click
-import pytest
-import requests
-from requests import Response
 from uvicorn.importer import import_from_string
 from starlette.testclient import TestClient as _TestClient, ASGI2App, ASGI3App
 
+try:
+    from requests import Response, Session
+except ImportError:
+    Response = None  # type: ignore
+    Session = None  # type: ignore
+
 from .applications import Index
 from .config import here, LOG_LEVELS, Config
 
@@ -54,7 +57,7 @@ class TestClient:
             self.uri, subprotocols=subprotocols, **kwargs
         )
 
-    def __enter__(self) -> requests.Session:
+    def __enter__(self) -> Session:
         return self.__client.__enter__()
 
     def __exit__(self, *args: typing.Any) -> None:
@@ -88,6 +91,8 @@ class LiteralOption(click.Option):
 @click.option("--args", cls=LiteralOption, default="[]")
 @click.argument("path", default="")
 def cmd_test(application: str, args: typing.List[str], path: str):
+    import pytest
+
     app: Index = import_from_string(application)
     pytest_args = [
         f"--rootdir={os.getcwd()}",
@@ -107,4 +112,4 @@ def cmd_test(application: str, args: typing.List[str], path: str):
             pytest_args.append(app.indexfile.get_filepath_from_path(path))
 
     with _TestClient(app):
-        pytest.main(pytest_args)
+        sys.exit(pytest.main(pytest_args))
